@@ -100,8 +100,10 @@ def ir_intensity_phonopy(
     # adapted from https://github.com/JaGeo/IR
     # TODO: Make directory indepndent
     cwd = os.getcwd()
+    print("Directory:", cwd)
     os.chdir(run_dir)
-    shutil.copy2(vasprun, "vasprun.xml")
+    if not os.path.exists(vasprun):
+        shutil.copy2(vasprun, "vasprun.xml")
     cmd = str("phonopy --fc vasprun.xml")
     os.system(cmd)
     born_file = os.path.join(os.getcwd(), BornFileName)
